@@ -6,7 +6,7 @@
 // and abiding by the rules of distribution of free software.
 // see the COPYRIGHT file for more details.
 // Authors: T. Gautier
-// $Id: givconfig.h,v 1.22 2011-02-04 14:50:07 bboyer Exp $
+// $Id: givconfig.h,v 1.22 2011-02-04 14:50:07 briceboyer Exp $
 // ==========================================================================
 /** @file givconfig.h
  * @ingroup system
@@ -64,10 +64,10 @@
 // - xx: major version number
 // - yy: minor version number
 // - zz: revision number
-#define GIVARO_MAJOR_VERSION    3
-#define GIVARO_MINOR_VERSION    7
-#define GIVARO_REVISION_VERSION 2
-#define GIVARO_VERSION          30702
+#define GIVARO_MAJOR_VERSION    4
+#define GIVARO_MINOR_VERSION    1
+#define GIVARO_REVISION_VERSION 1
+#define GIVARO_VERSION          40101
 
 // -- Defines this value both to compile the library of user program
 // value: integer that defines debug level trace information (not well defined)
@@ -84,50 +84,66 @@
 #define __STDC_LIMIT_MACROS
 #endif
 #include <stdint.h>
-#ifndef INT64_MAX
+#if !defined(INT64_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define INT64_MAX std::numeric_limits<int64_t>::max()
 #endif
 
-#ifndef UINT64_MAX
+#if !defined(UINT64_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define UINT64_MAX std::numeric_limits<uint64_t>::max()
 #endif
 
-#ifndef INT32_MAX
+#if !defined(INT32_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define INT32_MAX std::numeric_limits<int32_t>::max()
 #endif
 
-#ifndef UINT32_MAX
+#if !defined(UINT32_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define UINT32_MAX std::numeric_limits<uint32_t>::max()
 #endif
 
-#ifndef INT16_MAX
+#if !defined(INT16_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define INT16_MAX std::numeric_limits<int16_t>::max()
 #endif
 
-#ifndef UINT16_MAX
+#if !defined(UINT16_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define UINT16_MAX std::numeric_limits<uint16_t>::max()
 #endif
 
-#ifndef INT8_MAX
+#if !defined(INT8_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define INT8_MAX std::numeric_limits<int8_t>::max()
 #endif
 
-#ifndef UINT8_MAX
+#if !defined(UINT8_MAX)
+#if !defined(__CYGWIN__) && !defined(__PATHCC__)
 #pragma message "#warning somebody nasty previously included <stdint.h> without __STDC_LIMIT_MACROS :)"
+#endif
 #include <limits>
 #define UINT8_MAX std::numeric_limits<uint8_t>::max()
 #endif
@@ -207,31 +223,44 @@ typedef unsigned  __GIVARO_INT64     uint64_t;
 #  ifdef GIVARO_HAVE_ANSI_LIBRARY  // here is ANSI C++ header definition !!!
 #    include <sstream>
 #    define GIVARO_ASSERT(cond, msg) { \
-      if (!(cond)) {\
+    if (!(cond)) {\
         std::ostringstream ostr;\
         ostr << msg << "\nFile:"##__FILE__##", Line:" << __LINE__;\
         GivError::throw_error( GivError(ostr.str().c_str()) );\
-      }}
+    }}
 #    define GIVARO_ASSERT2(cond, msg1, msg2) { \
-      if (!(cond)) {\
+    if (!(cond)) {\
         std::ostringstream ostr;\
         ostr << msg1 << msg2 << "\nFile:"##__FILE__##", Line:" << __LINE__;\
         GivError::throw_error( GivError(ostr.str().c_str()) );\
-      }}
+    }}
+#    define GIVARO_ASSERT_MATHDIV0(cond, msg) { \
+    if (!(cond)) {\
+        std::ostringstream ostr;\
+        ostr << msg << "\nFile:"##__FILE__##", Line:" << __LINE__;\
+        throw  GivMathDivZero(ostr.str().c_str()) ;\
+    }}
+
 #  else
 #    include <sstream>
 #    define GIVARO_ASSERT(cond, msg) { \
-      if (!(cond)) {\
+    if (!(cond)) {\
         std::ostringstream ostr;\
         ostr << msg << "\nFile:" << __FILE__ << ", Line:" << __LINE__;\
         GivError::throw_error( GivError(ostr.str().c_str()) );\
-      }}
+    }}
 #    define GIVARO_ASSERT2(cond, msg1, msg2) { \
-      if (!(cond)) {\
+    if (!(cond)) {\
         std::ostringstream ostr;\
         ostr << msg1 << msg2 << "\nFile:" << __FILE__ << ", Line:" << __LINE__;\
         GivError::throw_error( GivError(ostr.str().c_str()) );\
-      }}
+    }}
+#    define GIVARO_ASSERT_MATHDIV0(cond, msg) { \
+    if (!(cond)) {\
+        std::ostringstream ostr;\
+        ostr << msg << "\nFile:"<<__FILE__<<", Line:" << __LINE__;    \
+        throw GivMathDivZero(ostr.str().c_str());\
+    }}
 #  endif
 
 #define GIVARO_REQUIRE(bool_expression, msg) GIVARO_ASSERT2(bool_expression, "Givaro required: ", msg)
@@ -242,6 +271,7 @@ typedef unsigned  __GIVARO_INT64     uint64_t;
 #define GIVARO_ASSERT2(cond, msg1, msg2)
 #define GIVARO_REQUIRE(ignore, msg) ((void) 0)
 #define GIVARO_ENSURE(ignore, msg) ((void) 0)
+#define GIVARO_ASSERT_MATHDIV0(cond, msg)
 // #define GIVARO_STATE(expression) do { (expression) } while (0)
 #define GIVARO_STATE(ignore)  ((void) 0)
 
@@ -277,18 +307,20 @@ typedef unsigned  __GIVARO_INT64     uint64_t;
 
 // -- Signed Traits (JGD 15.12.1999)
 // JGD 11.06.03
-#if !defined(__GNUC__) || (__GNUC__ != 2)
+#if !defined( __GNUC__ ) || ( __GNUC__ != 2 )
 // JGD 21.03.03
 #include <limits>
-template<class XXX> struct GIVARO_numeric_limits {
-    	typedef XXX self_type;
-	static XXX max() { return  std::numeric_limits<XXX>::max(); }
+template<class XXX>
+struct GIVARO_numeric_limits {
+    typedef XXX self_type;
+    static XXX max() { return  std::numeric_limits<XXX>::max(); }
 };
 #else
 #include <limits.h>
-template<class XXX> struct GIVARO_numeric_limits {
-    	typedef XXX self_type;
-	static XXX max() { return (XXX)(pow(2,8*sizeof(XXX))-1); }
+template<class XXX>
+struct GIVARO_numeric_limits {
+    typedef XXX self_type;
+    static XXX max() { return (XXX)(pow(2,8*sizeof(XXX))-1); }
 };
 
 /* Declared in <float.h> on ANSI C systems.  */
@@ -330,10 +362,10 @@ template<> inline int GIVARO_numeric_limits<int>::max() { return INT_MAX; }
 template<> inline unsigned int GIVARO_numeric_limits<unsigned int>::max() { return UINT_MAX; }
 template<> inline long GIVARO_numeric_limits<long>::max() { return LONG_MAX; }
 template<> inline unsigned long GIVARO_numeric_limits<unsigned long>::max() { return ULONG_MAX; }
-  #ifndef __GIVARO__DONOTUSE_longlong__
+#ifndef __GIVARO__DONOTUSE_longlong__
 template<> inline long long GIVARO_numeric_limits<long long>::max() { return LLONG_MAX; }
 template<> inline unsigned long long GIVARO_numeric_limits<unsigned long long>::max() { return ULLONG_MAX; }
-  #endif
+#endif
 
 #endif
 
@@ -350,7 +382,7 @@ template<> struct Signed_Trait<float>  : public GIVARO_numeric_limits<float> {
 template<> struct Signed_Trait<double>  : public GIVARO_numeric_limits<double> {
     typedef double signed_type;
     typedef double unsigned_type;
-  //    typedef unsigned long unsigned_type;
+    //    typedef unsigned long unsigned_type;
 };
 
 
@@ -395,27 +427,36 @@ template<> struct Signed_Trait<unsigned long>  : public GIVARO_numeric_limits<un
 };
 
 
-  #ifndef __GIVARO__DONOTUSE_longlong__
-  template<> struct Signed_Trait<long long>  : public GIVARO_numeric_limits<long long> {
+#ifndef __GIVARO__DONOTUSE_longlong__
+template<> struct Signed_Trait<long long>  : public GIVARO_numeric_limits<long long> {
     typedef long long signed_type;
     typedef unsigned long long unsigned_type;
-  };
+};
 
 
-  template<> struct Signed_Trait<unsigned long long>  : public GIVARO_numeric_limits<unsigned long long> {
+template<> struct Signed_Trait<unsigned long long>  : public GIVARO_numeric_limits<unsigned long long> {
     typedef long long signed_type;
     typedef unsigned long long unsigned_type;
-  };
-  #endif
-
+};
+#endif
 
 
 #if defined(_OPENMP) || defined(OMP_H) || defined(__OMP_H) || defined(__pmp_omp_h)
-#define GIVAVO_USES_OMP 1
-#else
-#undef GIVAVO_USES_OMP
+#  ifndef __GIVARO_USE_OPENMP
+#    define __GIVARO_USE_OPENMP 1
+#  endif
+//#else
+//#  undef __GIVARO_USE_OPENMP
 #endif
 
+#ifdef __GIVARO_HAVE_INT128
+/* Define int128 type */
+#define int128_t __int128_t
+
+/* Define uint128 type */
+#define uint128_t __uint128_t
+#endif
 
 #endif
-// vim:sts=8:sw=8:ts=8:noet:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
+/* -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+// vim:sts=4:sw=4:ts=4:et:sr:cino=>s,f0,{0,g0,(0,\:0,t0,+0,=s
